Enum diem_time_service::TimeService[][src]

pub enum TimeService {
    RealTimeService(RealTimeService),
    MockTimeService(MockTimeService),
}
TimeService abstracts all time-related operations in one place that can be easily mocked-out and controlled in tests or delegated to the actual underlying runtime (usually tokio). It’s provided as an enum so we don’t have to infect everything with a generic tag.

TimeService is async-focused: the sleep, interval, and timeout methods all return Futures and Streams. That said, TimeService supports non-async clients as well; simply use the sleep_blocking method instead of sleep. Note that the blocking call will actually block the current thread until the sleep time has elapsed.

TimeService tries to mirror the API provided by [tokio::time] to an extent. The primary difference is that all time is expressed in relative Durations. In other words, “sleep for 5s” vs “sleep until unix time 1607734460”. Absolute time is provided by TimeService::now which returns the current unix time.

Note: you must also include the TimeServiceTrait to use the actual time-related functionality.

Note: we have to provide our own Timeout and Interval types that use the Sleep future, since tokio’s implementations are coupled to its internal Sleep future.

Note: TimeService’s should be free (or very cheap) to clone and send around between threads. In production (without test features), this enum is a zero-sized type.

Variants

RealTimeService(RealTimeService)

Tuple Fields of RealTimeService

0: RealTimeService
MockTimeService(MockTimeService)

Tuple Fields of MockTimeService

0: MockTimeService

Implementations

Create a new real, production time service that actually uses the systemtime.

See RealTimeService.

Create a mock, simulated time service that does not query the system time and allows fine-grained control over advancing time and waking sleeping tasks.

See MockTimeService.